JwtKey class abstract

Available extensions
Annotations
  • @freezed

Constructors

JwtKey({required String kid, required String kty, required String alg, String? use, String? n, String? e, String? crv, String? x, String? y})
const
factory
JwtKey.fromJson(Map<String, dynamic> json)
factory

Properties

alg String
no setterinherited
copyWith → $JwtKeyCopyWith<JwtKey>
Create a copy of JwtKey with the given fields replaced by the non-null parameter values.
no setterinherited
crv String?
no setterinherited
e String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
kid String
no setterinherited
kty String
no setterinherited
n String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
use String?
no setterinherited
x String?
no setterinherited
y String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_JwtKey value)) → TResult

Available on JwtKey, provided by the JwtKeyPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_JwtKey value)?) → TResult?

Available on JwtKey, provided by the JwtKeyPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_JwtKey value)?, {required TResult orElse()}) → TResult

Available on JwtKey, provided by the JwtKeyPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String kid, String kty, String alg, String? use, String? n, String? e, String? crv, String? x, String? y)?, {required TResult orElse()}) → TResult

Available on JwtKey, provided by the JwtKeyPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this JwtKey to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String kid, String kty, String alg, String? use, String? n, String? e, String? crv, String? x, String? y)) → TResult

Available on JwtKey, provided by the JwtKeyPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String kid, String kty, String alg, String? use, String? n, String? e, String? crv, String? x, String? y)?) → TResult?

Available on JwtKey, provided by the JwtKeyPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited