SendOTPResponsePatterns extension

Adds pattern-matching-related methods to SendOTPResponse.

on

Methods

map<TResult extends Object?>(TResult $default(_SendOTPResponse value)) → TResult

Available on SendOTPResponse, provided by the SendOTPResponsePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SendOTPResponse value)?) → TResult?

Available on SendOTPResponse, provided by the SendOTPResponsePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SendOTPResponse value)?, {required TResult orElse()}) → TResult

Available on SendOTPResponse, provided by the SendOTPResponsePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String message)?, {required TResult orElse()}) → TResult

Available on SendOTPResponse, provided by the SendOTPResponsePatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String message)) → TResult

Available on SendOTPResponse, provided by the SendOTPResponsePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String message)?) → TResult?

Available on SendOTPResponse, provided by the SendOTPResponsePatterns extension

A variant of when that fallback to returning null